MsAuthenticate class

Constructors

MsAuthenticate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exchangeCodeForToken({required String tenantId, required String clientId, String? clientSecret, required String code, required String redirectUrl, String? scope}) Future<Map<Object?, Object?>?>
Exchange authorization code for token
getPlatformVersion() Future<String?>
loginWithMicrosoft({required String tenantId, required String clientId, String? clientSecret, required String redirectUrl, required String scope, String? tokenScope, String? nonce}) Future<Map<Object?, Object?>?>
Login with Microsoft Azure
logout() Future<void>
Logout and clean up
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited