MsAuthenticatePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MsAuthenticatePlatform
Implementers

Constructors

MsAuthenticatePlatform()
Constructs a MsAuthenticatePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exchangeCodeForToken({required String tenantId, required String clientId, String? clientSecret, required String code, required String redirectUrl, String? scope}) Future<Map<Object?, Object?>?>
getPlatformVersion() Future<String?>
loginWithMicrosoft({required String tenantId, required String clientId, String? clientSecret, required String redirectUrl, required String scope, String? tokenScope, String? nonce}) Future<Map<Object?, Object?>?>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MsAuthenticatePlatform
The default instance of MsAuthenticatePlatform to use.
getter/setter pair