MsAuthenticateWeb class

A web implementation of the MsAuthenticatePlatform of the MsAuthenticate plugin.

Inheritance

Constructors

MsAuthenticateWeb()
Constructs a MsAuthenticateWeb

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exchangeCodeForToken({required String tenantId, required String clientId, String? clientSecret, required String code, required String redirectUrl, String? scope}) Future<Map<Object?, Object?>?>
override
generateSecureState([int byteLength = 32]) String
getPlatformVersion() Future<String?>
Returns a String containing the version of the platform.
override
loginWithMicrosoft({required String tenantId, required String clientId, String? clientSecret, required String redirectUrl, required String scope, String? tokenScope, String? nonce}) Future<Map<Object?, Object?>?>
override
logout() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void